==> nextcloud-30.0.13.tgz: nextcloud/apps/files_reminders/l10n/da.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Filpåmindelser",
    "Reminder for {name}" : "Påmindelse af {name}",
    "View file" : "Vis fil",
    "View folder" : "Vis mappe",
    "Files reminder" : "Filpåmindelse",
    "The \"files_reminders\" app can work properly." : "Appen \"files_reminders\" kan fungere korrekt.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Appen \"files_reminders\" skal bruge notifikationsappen for at fungere korrekt. Du bør enten aktivere meddelelser eller deaktivere files_reminder.",
    "Set file reminders" : "Sæt filpåmindelser",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Filpåmindelser**\n\nIndstil filpåmindelser.\n\nBemærk: For at bruge appen \"Filpåmindelser\" skal du sikre dig, at appen \"Meddelelser\" er installeret og aktiveret. Appen 'Notifikationer' giver de nødvendige API'er for at appen 'Filpåmindelser' kan fungere korrekt.",
    "Set reminder for \"{fileName}\"" : "Indstil påmindelse for \"{fileName}\"",
    "Set reminder at custom date & time" : "Indstil påmindelse til tilpasset dato og klokkeslæt",
    "Clear reminder" : "Ryd påmindelse",
    "Please choose a valid date & time" : "Vælg en gyldig dato & tid",
    "Reminder set for \"{fileName}\"" : "Påmindelse indstillet til \"{fileName}\"",
    "Failed to set reminder" : "Kunne ikke indstille påmindelsen",
    "Reminder cleared for \"{fileName}\"" : "Påmindelsen blev ryddet for \"{fileName}\"",
    "Failed to clear reminder" : "Kunne ikke rydde påmindelse",
    "We will remind you of this file" : "Vi vil minde dig om denne fil",
    "Cancel" : "Annuller",
    "Set reminder" : "Sæt påmindelse",
    "Reminder set" : "Påmindelse sat",
    "Set custom reminder" : "Sæt brugerdefineret påmindelse",
    "Later today" : "Senere i dag",
    "Set reminder for later today" : "Sæt påmindelse for senere i dag",
    "Tomorrow" : "I morgen",
    "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
    "This weekend" : "Denne weekend",
    "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
    "Next week" : "Næste uge",
    "Set reminder for next week" : "Sæt påmindelse for næste weekend",
    "This files_reminder can work properly." : "Denne files_reminder kan fungere korrekt.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Files_reminder-appen skal bruge notifikationsappen for at fungere korrekt. Du bør enten aktivere meddelelser eller deaktivere files_reminder."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.14.tgz: nextcloud/apps/files_reminders/l10n/da.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Filpåmindelser",
    "Reminder for {name}" : "Påmindelse af {name}",
    "View file" : "Vis fil",
    "View folder" : "Vis mappe",
    "Files reminder" : "Filpåmindelse",
    "The \"files_reminders\" app can work properly." : "Appen \"files_reminders\" kan fungere korrekt.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Appen \"files_reminders\" skal bruge notifikationsappen for at fungere korrekt. Du bør enten aktivere meddelelser eller deaktivere files_reminder.",
    "Set file reminders" : "Sæt filpåmindelser",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Filpåmindelser**\n\nIndstil filpåmindelser.\n\nBemærk: For at bruge appen \"Filpåmindelser\" skal du sikre dig, at appen \"Meddelelser\" er installeret og aktiveret. Appen 'Notifikationer' giver de nødvendige API'er for at appen 'Filpåmindelser' kan fungere korrekt.",
    "Set reminder for \"{fileName}\"" : "Indstil påmindelse for \"{fileName}\"",
    "Clear reminder" : "Ryd påmindelse",
    "Please choose a valid date & time" : "Vælg en gyldig dato & tid",
    "Reminder set for \"{fileName}\"" : "Påmindelse indstillet til \"{fileName}\"",
    "Failed to set reminder" : "Kunne ikke indstille påmindelsen",
    "Reminder cleared for \"{fileName}\"" : "Påmindelsen blev ryddet for \"{fileName}\"",
    "Failed to clear reminder" : "Kunne ikke rydde påmindelse",
    "We will remind you of this file" : "Vi vil minde dig om denne fil",
    "Cancel" : "Annuller",
    "Set reminder" : "Sæt påmindelse",
    "Reminder set" : "Påmindelse sat",
    "Later today" : "Senere i dag",
    "Set reminder for later today" : "Sæt påmindelse for senere i dag",
    "Tomorrow" : "I morgen",
    "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
    "This weekend" : "Denne weekend",
    "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
    "Next week" : "Næste uge",
    "Set reminder for next week" : "Sæt påmindelse for næste weekend",
    "This files_reminder can work properly." : "Denne files_reminder kan fungere korrekt.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Files_reminder-appen skal bruge notifikationsappen for at fungere korrekt. Du bør enten aktivere meddelelser eller deaktivere files_reminder.",
    "Set reminder at custom date & time" : "Indstil påmindelse til tilpasset dato og klokkeslæt",
    "Set custom reminder" : "Sæt brugerdefineret påmindelse"
},
"nplurals=2; plural=(n != 1);");
